<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar" sourcelanguage="en">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Copy</source>
        <translation>نسخ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Rename</source>
        <translation>إعادة تسمية</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Move</source>
        <translation>نقل</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Edit</source>
        <translation>تحرير</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Share</source>
        <translation>مشاركة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Change icon</source>
        <translation>تغيير الرمز</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Compress</source>
        <translation>أضغط</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Documents</source>
        <translation>المستندات</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Images</source>
        <translation>الصور</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Sounds</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Videos</source>
        <translation>الفيديو</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Added to Clipboard</source>
        <translation>وأضاف إلى الحافظة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation>خطأ : لا شيء مختارة للصق</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Cannot create symlink in this folder</source>
        <translation>لا يمكن انشاء ارتباط بهذا المجلد</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>لايوجد مساحة كافية للمتابعة.</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>ليس لديك الصلاحيات للمتابعة.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>About</source>
        <translation>عن البرنامج</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>Broken Symlink!</source>
        <translation>الرابط ضعيف!</translation>
    </message>
</context>
<context>
    <name>BookWindow</name>
    <message>
        <location filename="../bookwindow.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>المفضلة</translation>
    </message>
</context>
<context>
    <name>Home</name>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Home folder</source>
        <translation>مسار البداية</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Compress destination</source>
        <translation>مسار الضغط</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Extract destination</source>
        <translation>مسار فك الضغط</translation>
    </message>
    <message>
        <location filename="../home.cpp" line="10"/>
        <source>Symlink destination</source>
        <translation>مسار الإرتباط</translation>
    </message>
</context>
<context>
    <name>Clipboard</name>
    <message>
        <location filename="../clipboard.cpp" line="10"/>
        <source>Clipboard</source>
        <translation>الحافظة</translation>
    </message>
</context>
<context>
    <name>Bookmarks</name>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Bookmarks</source>
        <translation>المفضلة</translation>
    </message>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <location filename="../bookmarks.cpp" line="10"/>
        <source>Rename</source>
        <translation>إعادة تسمية</translation>
    </message>
</context>
<context>
    <name>ToolsDialog</name>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Tools</source>
        <translation>الأدوات</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Add to Bookmarks</source>
        <translation>أضافة الى المفضلة</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new folder</source>
        <translation>إنشاء مجلد جديد</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new document</source>
        <translation>إنشاء مستند جديد</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Open terminal here</source>
        <translation>فتح الترمنل هنا</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Create new symlink</source>
        <translation>انشاء ارتباط جديد</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Sort</source>
        <translation>ترتيب</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Paste from clipboard</source>
        <translation>لصق من الحافظة</translation>
    </message>
    <message>
        <location filename="../toolsdialog.cpp" line="10"/>
        <source>Cut from clipboard</source>
        <translation>قطع من الحافظة</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="10"/>
        <source>ERROR: Nothing selected to paste</source>
        <translation>خطأ : لا شيء مختارة للصق</translation>
    </message>
</context>
<context>
    <name>Share</name>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Share</source>
        <translation>مشاركة</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via bluetooth</source>
        <translation>أرسال بواسطة البلوتوث</translation>
    </message>
    <message>
        <location filename="../share.cpp" line="10"/>
        <source>Send via e-mail</source>
        <translation>أرسال بواسطة الأيميل</translation>
    </message>
</context>
<context>
    <name>QtCopyDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1 of %2 completed</source>
        <translation>1% للأنهاء %2 و</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Warning</source>
        <translation>تنبيه</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>تنبيه</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source doesn&apos;t exist.</source>
        <translation>.لايوجد أي مصدر للملفات.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>No enough space for copy the file.</source>
        <translation>لايوجد مساحة كافية لنسخ الملف.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source file is a directory. Omitting source directory.</source>
        <translation>الملف المصدر مسار. تجاهل مصدر المسار.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source directory is a file. Omitting source file.</source>
        <translation>المصدر مجلد لملف. تجاهل مصدر الملف.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Path to destination does not exist.</source>
        <translation>مسار الملف غير موجود.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create destination directory.</source>
        <translation>لايمكن أنشاء المسار مباشرة.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open source file. Please check permissions.</source>
        <translation> لايمكن فتح الملف المصدر. تأكد من الصلاحيات. </translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot open destination file. Please check permissions.</source>
        <translation>لايمكن فتح مسار الملف . تأكد من الصلاحيات.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Force: Cannot remove destination file.</source>
        <translation>لايمكن حذف مسار الملف.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot create symbolic link targeting to source.</source>
        <translation>لايمكن أنشاء وصلة لرابط المصدر.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot read source file.</source>
        <translation>لايمكن قراءة الملف المصدر.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot write destination file.</source>
        <translation>لايمكن الكتابة على مسار الملف.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cannot remove source.</source>
        <translation>لايمكن حذف المصدر.</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>100% of %1 (Done)</source>
        <translation>100% of %1 (Done)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copying...</source>
        <translation>جاري النسخ ...</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>%1% of %2 (%3)</source>
        <translation>%1 of %2 (%3)</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Done</source>
        <translation>إنهاء</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>المسار</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Close</source>
        <translation>أغلاق</translation>
    </message>
</context>
<context>
    <name>QtOverwriteDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Copy Warning</source>
        <translation>تنبيه</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination</source>
        <translation>المسار</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>تجاهل</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Overwrite</source>
        <translation>إعادة كتابة</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Destination already exists.</source>
        <translation>المسار موجود بالفعل.</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Preparing to delete %1 files</source>
        <translation>التحضير للحذف %1 الملفات</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting %1</source>
        <translation>حذف %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Error deleting %1</source>
        <translation>خطأ بالحذف %1</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Delete Finished Ok</source>
        <translation>تم الحذف بنجاح</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Abort</source>
        <translation>تجاهل</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Close</source>
        <translation>أغلاق</translation>
    </message>
    <message>
        <location filename="../deletedialog.cpp" line="10"/>
        <source>Deleting files</source>
        <translation>حذف الملفات</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Apply</source>
        <translation>تطبيق</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Home folder</source>
        <translation>مسار البداية</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Icons Style</source>
        <translation>أشكال الرموز</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Text Editor</source>
        <translation>محرر النصوص</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable root access (restart needed)</source>
        <translation>تفعيل الصلاحيات لتعديل</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show hidden files and folders</source>
        <translation>مشاهدة الملفات والمجلدات المخفية</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show thumbnails for images</source>
        <translation> عرض الصور مصغرة</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Show details for files</source>
        <translation>عرض تفاصيل عن الملفات</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Delete items from clipboard on Paste</source>
        <translation>حذف البيانات من حافظة اللصق</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Enable multiselection</source>
        <translation>تفعيل التحديد المتعدد</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Auto select items in clipboard</source>
        <translation>الأختار التلقائي للعناصر من حافظة اللصق</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Orientation</source>
        <translation>التدوير</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Automatic</source>
        <translation>تلقائي</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Portrait</source>
        <translation>عامودي</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="10"/>
        <source>Landscape</source>
        <translation>أفقي</translation>
    </message>
</context>
<context>
    <name>NewFolder</name>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Create folder</source>
        <translation>إنشاء مجلد</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Enter new folder name</source>
        <translation>ضع أسم للمجلد الجديد</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Accept</source>
        <translation>تطبيق</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Cannot create folder. Try another name.</source>
        <translation>لايمكن أنشاء المجلد. حاول بأسم أخر.</translation>
    </message>
</context>
<context>
    <name>QtOtherDialog</name>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Retry</source>
        <translation>إعادة</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Skip</source>
        <translation>تجاهل</translation>
    </message>
    <message>
        <location filename="../qtcopydialog.cpp" line="10"/>
        <source>Source</source>
        <translation>المصدر</translation>
    </message>
    <message>
        <location filename="../newfolder.cpp" line="10"/>
        <source>Destination</source>
        <translation>المسار</translation>
    </message>
</context>
<context>
    <name>Rename</name>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Renaming</source>
        <translation>إعادة التسمية</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Enter new name</source>
        <translation>أدخل الأسم الجديد</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Accept</source>
        <translation>تطبيق</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../rename.cpp" line="10"/>
        <source>Cannot rename. Try another name.</source>
        <translation>لايمكن إعادة التسمة . حاول بأسم آخر.</translation>
    </message>
</context>
<context>
    <name>AskDialog</name>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Deleting</source>
        <translation>حذف</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Change icon</source>
        <translation>تغيير الرمز</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Apply to subfolders?</source>
        <translation>تنطبق على المجلدات الفرعية؟</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>هل أنت متأكد من الحذف %1؟</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>هل أنت متأكد من حذف العناصر المحدد؟</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>Yes</source>
        <translation>نعم</translation>
    </message>
    <message>
        <location filename="../askdialog.cpp" line="10"/>
        <source>No</source>
        <translation>لا</translation>
    </message>
</context>
<context>
    <name>Sort</name>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Sort</source>
        <translation>الترتيب</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Ascending</source>
        <translation>تصاعدي</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Descending</source>
        <translation>تنازلي</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (A-Z)</source>
        <translation>الأسم أ-ي</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Name (Z-A)</source>
        <translation>الأسم ي-أ</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (olders first)</source>
        <translation>التاريخ الأقدم أولاً</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Date (recents first)</source>
        <translation>التاريخ الأحدث أولاً</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (smallers first)</source>
        <translation>الحجم الأصغر أولاً</translation>
    </message>
    <message>
        <location filename="../sort.cpp" line="10"/>
        <source>Size (biggers first)</source>
        <translation>الحجم الأكبر أولاً</translation>
    </message>
</context>
<context>
    <name>NewDoc</name>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>New document</source>
        <translation>مستند جديد</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Create</source>
        <translation>إنشاء</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter name for new document</source>
        <translation>أدخل الأسم الجديد للمستند</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Enter a valid file name</source>
        <translation>أدخل أسم صحيح للملف</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>The file already exists. Try another name</source>
        <translation>الملف موجود بالفعل. حاول بأسم آخر</translation>
    </message>
    <message>
        <location filename="../newdoc.cpp" line="10"/>
        <source>Cannot create the file. Check permissions</source>
        <translation>لايمكن إنشاء الملف. تأكد من الصلاحيات</translation>
    </message>
</context>
<context>
    <name>Error</name>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../error.cpp" line="10"/>
        <source>Accept</source>
        <translation>تطبيق</translation>
    </message>
</context>
<context>
    <name>CompressDlg</name>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compress</source>
        <translation>ضغط</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>File name</source>
        <translation>أسم الملف</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Compression</source>
        <translation>طريقة الضغط</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>مسار المجلد</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>تطبيق</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>The file already exists. Try another name.</source>
        <translation>الملف موجود بالفعل. حاول بأسم آخر.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>لايوجد مساحة كافية للمتابعة.</translation>
    </message>
    <message>
        <location filename="../compressdlg.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>لاتمتلك الصلاحيات للمتابعة.</translation>
    </message>
</context>
<context>
    <name>Compress</name>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Compressing</source>
        <translation>ضغط</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Adding %1...</source>
        <translation>أضافة %1...</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>تمت العملية بنجاح.</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../compress.cpp" line="10"/>
        <source>Close</source>
        <translation>أغلاق</translation>
    </message>
</context>
<context>
    <name>Unzip</name>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Extract files</source>
        <translation>فك ضغط الملف</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>Not enough space to proceed.</source>
        <translation>لاتمتلك مساحة كافية للمتابعة.</translation>
    </message>
    <message>
        <location filename="../unzip.cpp" line="10"/>
        <source>You don&apos;t have permissions to proceed.</source>
        <translation>لاتمتلك الصلاحيات للمتابعة.</translation>
    </message>
</context>
<context>
    <name>UnzipDlg</name>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Extract</source>
        <translation>فك الضغط</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Destination folder</source>
        <translation>مسار المجلد</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Keep existing files</source>
        <translation>أبقاء الملفات الموجودة</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Accept</source>
        <translation>تطبيق</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../unzipdlg.cpp" line="10"/>
        <source>Password</source>
        <translation>كلمة السر</translation>
    </message>
</context>
<context>
    <name>Extract</name>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting</source>
        <translation>فك الضغط</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Extracting %1...</source>
        <translation>إستخراج %1...</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Operation finished.</source>
        <translation>تمت العملية بنجاح.</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Error extracting files. Incorrect password?</source>
        <translation>ملفات استخراج خطأ. غير صحيح كلمة السر؟</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <location filename="../extract.cpp" line="10"/>
        <source>Close</source>
        <translation>إغلاق</translation>
    </message>
</context>
<context>
    <name>About</name>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>About FileBox</source>
        <translation>عن البرنامج</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="10"/>
        <source>File Manager for Maemo 5</source>
        <translation>مدير الملفات لميمو 5</translation>
    </message>
</context>
<context>
    <name>selectIcon</name>
    <message>
        <location filename="../selecticon.cpp" line="10"/>
        <source>Select icon</source>
        <translation>حدد أيقونة</translation>
    </message>
</context>
</TS>
